@@ -1185,7 +1185,7 @@ class RtFo(object):
                 slc1[rdx] = rii
                 slc2[rdx] = rii + 1
 
-                dat = rpp * dat[slc1] + (1.0 - rpp) * dat[slc2]
+                dat = rpp * dat[tuple(slc1)] + (1.0 - rpp) * dat[tuple(slc2)]
                 _ = dms.pop(rdx)
                 _ = idx.pop(rdx)
                 _ = rng.pop(rdx)
