@@ -432,16 +432,25 @@ class Fo(object):
         self.s1 = float(solar_1) * (10e6 / self.wvl_sel[-1]) ** 2
 
         # load RT LUT
+        # check if LUT file is available
         self.logger.info("Loading RT LUT...")
         if os.path.isfile(options["EnMAP"]["Retrieval"]["fn_LUT"]):
             self.fn_table = options["EnMAP"]["Retrieval"]["fn_LUT"]
         else:
             self.path_sicorlib = os.path.dirname(pkgutil.get_loader("sicor").path)
-            if os.path.isfile(os.path.join(self.path_sicorlib, 'AC', 'data', 'EnMAP_LUT_MOD5_formatted_1nm')):
-                self.fn_table = os.path.join(self.path_sicorlib, 'AC', 'data', 'EnMAP_LUT_MOD5_formatted_1nm')
+            if os.path.isfile(os.path.join(self.path_sicorlib, "AC", "data", "EnMAP_LUT_MOD5_formatted_1nm")):
+                self.fn_table = os.path.join(self.path_sicorlib, "AC", "data", "EnMAP_LUT_MOD5_formatted_1nm")
             else:
-                raise FileNotFoundError('LUT file was not found. Make sure to indicate path in options file or to'
-                                        'store the LUT at /sicor/AC/data/ directory, otherwise, the AC will not work.')
+                raise FileNotFoundError("LUT file was not found. Make sure to indicate path in options file or to "
+                                        "store the LUT at /sicor/AC/data/ directory, otherwise, the AC will not work.")
+
+        # check if LUT is a regular file (not only an LFS pointer)
+        try:
+            assert os.path.getsize(self.fn_table) > 1000
+            self.logger.info("LUT file was properly downloaded and is available for AC!")
+        except AssertionError:
+            raise AssertionError("LUT file only represents an LFS pointer. Make sure to download the file following "
+                                 "the installation documentation on Git. Otherwise, the AC will not work.")
 
         luts, axes_x, axes_y, wvl, lut1, lut2, xnodes, nm_nodes, ndim, x_cell = read_lut_enmap_formatted(
             file_lut=self.fn_table)
