@@ -27,9 +27,8 @@
 from scipy.linalg import eigh, norm
 from scipy.spatial import KDTree
 from scipy.stats import linregress
-from skimage.segmentation import slic
 import numpy as np
-from multiprocessing import Pool, cpu_count
+from multiprocessing import Pool
 
 
 def SLIC_segmentation(data_rad_all, n_pca, segs):
@@ -41,6 +40,8 @@ def SLIC_segmentation(data_rad_all, n_pca, segs):
     :param segs:         number of segments
     :return:             flattened radiance data array, number of segments, array of segment labels for each pixel
     """
+    # importing skimage here avoids ImportError: dlopen: cannot load any more object with static TLS
+    from skimage.segmentation import slic
 
     # Change from BIP to a long list of spectra
     rows, bands, cols = data_rad_all.shape[0], data_rad_all.shape[2], data_rad_all.shape[1]
